==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/ko-KR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => '이 사용자는 로그인 할 수 있음',
    'activated_disabled_help_text' => '자신의 계정에 대한 활성 상태는 편집 할 수 없습니다.',
    'assets_user'       => '자산 보유자 :name',
    'bulk_update_warn'	=> '당신은 :user_count 사용자의 속성을 수정하려고 합니다. 이 양식을 사용하여 자신의 사용자 속성을 변경할 수 없으며 ,사용자 자신의 개인 정보를 개별적으로 수정해야합니다.',
    'bulk_update_help'	=> '이 양식을 사용하면 한 번에 여러 사용자를 갱신할 수 있습니다. 변경할 필요가 있는 항목만 채우세요. 아무 것도 입력하지 않으면 변경되지 않습니다.',
    'current_assets'    => '현재 이 사용자에게 반출 된 자산',
    'clone'             => '사용자 복제',
    'contact_user'      => '연락처 :name',
    'edit'              => '사용자 편집',
    'filetype_info'     => '허용되는 형식들은 png, gif, jpeg, doc, docx, pdf, txt, zip, rar 입니다.',
    'history_user'      => '이력 :name',
    'info'				=> '정보',
    'restore_user'		=> '그것들을 복원하려면 여기를 클릭하세요.',
    'last_login'        => '마지막 로그인',
    'ldap_config_text'  => 'LDAP 구성 설정들은 Admin > Settings 에서 찾을 수 있습니다. (부가적으로) 선택된 장소는 불러온 모든 사용자들에게 설정됩니다.',
    'print_assigned'    => 'Assigned 자산 모두 인쇄',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => '소프트웨어 반출 목록 :name',
    'send_email_help'   => '이 사용자에게 자격 증명을 보내려면 이메일 주소를 입력해야 합니다. 자격 증명을 이메일로 보내는 것은 사용자 생성 시에만 수행할 수 있습니다. 암호는 단방향 해시에 저장되며 한 번 저장하면 재열람 할 수 없습니다.',
    'view_user'         => '사용자 보기 :name',
    'usercsv'           => 'CSV 파일',
    'two_factor_admin_optin_help' => '현재 관리 설정이 두가지 인증방법을 선택적으로 실행하게 되어 있습니다.  ',
    'two_factor_enrolled' => '2FA 장치 등록 ',
    'two_factor_active'   => '2FA 활성화 ',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/ko-KR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => '이 사용자는 로그인 할 수 있음',
    'activated_disabled_help_text' => '자신의 계정에 대한 활성 상태는 편집 할 수 없습니다.',
    'assets_user'       => '자산 보유자 :name',
    'bulk_update_warn'	=> '당신은 :user_count 사용자의 속성을 수정하려고 합니다. 이 양식을 사용하여 자신의 사용자 속성을 변경할 수 없으며 ,사용자 자신의 개인 정보를 개별적으로 수정해야합니다.',
    'bulk_update_help'	=> '이 양식을 사용하면 한 번에 여러 사용자를 갱신할 수 있습니다. 변경할 필요가 있는 항목만 채우세요. 아무 것도 입력하지 않으면 변경되지 않습니다.',
    'current_assets'    => '현재 이 사용자에게 반출 된 자산',
    'clone'             => '사용자 복제',
    'contact_user'      => '연락처 :name',
    'edit'              => '사용자 편집',
    'filetype_info'     => '허용되는 형식들은 png, gif, jpeg, doc, docx, pdf, txt, zip, rar 입니다.',
    'history_user'      => '이력 :name',
    'info'				=> '정보',
    'restore_user'		=> '그것들을 복원하려면 여기를 클릭하세요.',
    'last_login'        => '마지막 로그인',
    'ldap_config_text'  => 'LDAP 구성 설정들은 Admin > Settings 에서 찾을 수 있습니다. (부가적으로) 선택된 장소는 불러온 모든 사용자들에게 설정됩니다.',
    'print_assigned'    => 'Assigned 자산 모두 인쇄',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => '소프트웨어 반출 목록 :name',
    'send_email_help'   => '이 사용자에게 자격 증명을 보내려면 이메일 주소를 입력해야 합니다. 자격 증명을 이메일로 보내는 것은 사용자 생성 시에만 수행할 수 있습니다. 암호는 단방향 해시에 저장되며 한 번 저장하면 재열람 할 수 없습니다.',
    'view_user'         => '사용자 보기 :name',
    'usercsv'           => 'CSV 파일',
    'two_factor_admin_optin_help' => '현재 관리 설정이 두가지 인증방법을 선택적으로 실행하게 되어 있습니다.  ',
    'two_factor_enrolled' => '2FA 장치 등록 ',
    'two_factor_active'   => '2FA 활성화 ',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];
